Method: Thor::Base::ClassMethods#stop_on_unknown_option?
- Defined in:
- lib/thor/base.rb
#stop_on_unknown_option?(command_name) ⇒ Boolean
If true, option parsing is suspended as soon as an unknown option or a regular argument is encountered. All remaining arguments are passed to the command as regular arguments.
202 203 204 |
# File 'lib/thor/base.rb', line 202 def stop_on_unknown_option?(command_name) #:nodoc: false end |